@@ -1,23 +1,17 @@
 from .pageobjectbase import PageObjectBase
 from .pageobject import PageObject
-from selenium.common.exceptions import StaleElementReferenceException
+from . import commands
 
 
 class PageObjectList(PageObjectBase):
 
-    def __init__(self, locator, parent, chain=True, name=None, children_class=None, children_locator=None, count_locator=None):
+    def __init__(self, locator, chain=True, children_class=None, children_locator=None, count_locator=None):
         self._locator = locator
-        self.parent = parent
         self._chain = chain
-        self._name = name
         self._children_class = children_class
         self._children_locator = children_locator
         self._count_locator = count_locator
-
-        try:
-            self.parent._register_child(self)
-        except AttributeError:
-            pass # we don't have a parent or the parent is not a PageObject
+        self._parent = None
 
 
     def __bool__(self):
@@ -32,19 +26,32 @@ class PageObjectList(PageObjectBase):
         return len(self.children)
 
 
+    @property
+    def _children_count(self):
+        return len(self.webdriver.find_elements_by_xpath(self.count_locator))
+
+
     @property
     def children(self):
-        children_count = len(self.webdriver.find_elements_by_xpath(self.count_locator))
         children = []
-        for i in range(children_count):
+        ChildrenClass = self.children_class
+        for i in range(self._children_count):
             locator = self.children_locator.format(i+1)
-            ChildrenClass = self.children_class
-            child = ChildrenClass(locator, self, chain=False)
+            child = ChildrenClass(locator, chain=False)
             child.index = i
+            child._parent = self
             children.append(child)
         return children
 
 
+    def _get_child_name(self, child_po):
+        return '{}[{}]'.format(self.name, child_po.index)
+
+
+    def _get_child_full_name(self, child_po):
+        return '{}[{}]'.format(self.full_name, child_po.index)
+
+
     @property
     def children_class(self):
         if self._children_class:
@@ -83,16 +90,6 @@ class PageObjectList(PageObjectBase):
             return self.locator
 
 
-    def index(self, value, attempt=1):
-        if attempt == 1:
-            self.logger.info('getting index of "{}" within {}'.format(value, self._log_id_short))
-        self.logger.debug('getting index of "{}" within page object, attempt number {}; {}'.format(value, attempt, self._log_id_long))
-        try:
-            index = [item.text for item in self[:]].index(value)
-            self.logger.info('index of "{}" within {} is {}'.format(value, self._log_id_short, index))
-            self.logger.debug('index of "{}" within page object is {}; {}'.format(value, index, self._log_id_long))
-            return index
-        except StaleElementReferenceException:
-            self.logger.debug('getting index failed, trying again')
-            return self.index(value, attempt=attempt+1)
+    # commands
+    index = commands.index
 
